//! Handle requests for cover images.

use std::sync::Arc;

use crate::{app_state::AppState, cache, handlers::error::HandlerError};
use poem::{
    error::NotFoundError,
    handler,
    web::{headers::ContentType, Data, Path},
    Response,
};

/// Handle a request for the cover image of book with id `id`.
#[handler]
pub async fn handler(id: Path<u64>, state: Data<&Arc<AppState>>) -> Result<Response, poem::Error> {
    let book = state
        .calibre
        .scalar_book(*id)
        .map_err(HandlerError::DataError)?;
    let cover_path = state.config.library_path.join(book.path).join("cover.jpg");

    let mut cover = cache::get_thumbnail(&cover_path, &state.config.cache_path)
        .await
        .map_err(|_| NotFoundError)?;
    crate::handlers::download::handler("cover.jpg", cover, &ContentType::jpeg().to_string()).await
}
